import Highlight from '@tiptap/extension-highlight';
import TextAlign from '@tiptap/extension-text-align';
import { useEditor, EditorContent } from '@tiptap/react';
import StarterKit from '@tiptap/starter-kit';
import React from 'react';
import { Iframe } from '../../extensions/Iframe.js';
import '../../globals.css.js';
import './index.css.js';

var MenuBar = function (_a) {
  var editor = _a.editor;
  if (!editor) {
    return null;
  }
  return /*#__PURE__*/React.createElement("div", {
    className: "menuBar"
  }, /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().toggleHeading({
        level: 1
      }).run();
    },
    className: editor.isActive("heading", {
      level: 1
    }) ? "is-active" : ""
  }, "h1"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().toggleHeading({
        level: 2
      }).run();
    },
    className: editor.isActive("heading", {
      level: 2
    }) ? "is-active" : ""
  }, "h2"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().toggleHeading({
        level: 3
      }).run();
    },
    className: editor.isActive("heading", {
      level: 3
    }) ? "is-active" : ""
  }, "h3"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().setParagraph().run();
    },
    className: editor.isActive("paragraph") ? "is-active" : ""
  }, "paragraph"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().toggleBold().run();
    },
    className: editor.isActive("bold") ? "is-active" : ""
  }, "bold"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().toggleItalic().run();
    },
    className: editor.isActive("italic") ? "is-active" : ""
  }, "italic"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().toggleStrike().run();
    },
    className: editor.isActive("strike") ? "is-active" : ""
  }, "strike"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().toggleHighlight().run();
    },
    className: editor.isActive('highlight') ? 'is-active' : ''
  }, "highlight"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().setTextAlign("left").run();
    },
    className: editor.isActive({
      textAlign: "left"
    }) ? "is-active" : ""
  }, "left"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().setTextAlign("center").run();
    },
    className: editor.isActive({
      textAlign: "center"
    }) ? "is-active" : ""
  }, "center"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().setTextAlign("right").run();
    },
    className: editor.isActive({
      textAlign: "right"
    }) ? "is-active" : ""
  }, "right"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return editor.chain().focus().setTextAlign("justify").run();
    },
    className: editor.isActive({
      textAlign: "justify"
    }) ? "is-active" : ""
  }, "justify"), /*#__PURE__*/React.createElement("button", {
    onClick: function () {
      return openModal(editor);
    }
  }, "Mark"));
};
var openModal = function (editor) {
  console.log("OPEN");
  editor.chain().focus().setIframe({
    src: "https://www.openstreetmap.org/export/embed.html?bbox=-0.004017949104309083%2C51.47612752641776%2C0.00030577182769775396%2C51.478569861898606&layer=mapnik"
  }).run();
};
var LidiaEditor = function (_a) {
  var className = _a.className,
    html = _a.html,
    setHtml = _a.setHtml;
  var editor = useEditor({
    onUpdate: function (_a) {
      var editor = _a.editor;
      setHtml(editor.getHTML());
    },
    extensions: [StarterKit, TextAlign.configure({
      types: ["heading", "paragraph"]
    }), Highlight, Iframe],
    content: html
  });
  return /*#__PURE__*/React.createElement("div", {
    className: "lidiaEditor ".concat(className)
  }, /*#__PURE__*/React.createElement(MenuBar, {
    editor: editor
  }), /*#__PURE__*/React.createElement("div", {
    className: "editorContainer"
  }, /*#__PURE__*/React.createElement(EditorContent, {
    className: "editor",
    editor: editor
  })));
};

export { LidiaEditor };
